function [time,p,dddp,dtdh] = get_tt_PP300P (depth, delta)
% Matlab function to find travel time and ray par. at many offests
% Usage   [time,p,dddp,dtdh] = get_tt_PP300P (depth, delta)
% This program interpolates and matches ray parameters to find the travel 
% time and ray parameter, using the IASPI91 model, for an earthquake at
% a given depth.

dpt=300;					% convert at 660km
phase1 = 'P     ';
phase2 = 'P     ';
delt1 = [ 26: 0.5: 105]; 		        % table one - P wave from 660
[t1, p1, dddp660,dtdh] = get_ttt(phase2,depth, delt1);% original time and ray parm.
close = [ .01 : 0.05 : 2.2];			
[t2, p2, dddp2] = get_ttt (phase1, dpt, close); % table 2- s wave 660 up

% These evaluate the S waves at the P ray parms.
tPP300Pup = interpol(p2,t2,p1); dPP300Pup = interpol(p2,close',p1);
dddpPP300P = interpol(p2,dddp2,p1); 

time1 = t1 + 2*tPP300Pup;
dist1 = delt1' + dPP300Pup*2;
dddp1 = dddp660 + 2*dddpPP300P;

% interpolate tables to get values at desired distances
p=interpol(dist1,p1,delta');
time=interpol(dist1,time1,delta');
dddp=interpol(dist1,dddp1,delta');
dtdh=-1*interpol(dist1,dtdh,delta');

% set interpolate = 1 for interpolation, 0 for extrapolation, then divide to
% give values of inf for extrapolation
interpolate=(delta'>=min(dist1)) & (delta'<=max(dist1));    
p=p./interpolate;
dddp=dddp./interpolate;
dtdh=dtdh./interpolate;
time=time./interpolate;
