function [time,p,dddp]=get_tt_Ps(depth,delta);
%   get_tt_Ps     get travel times for Ps
% USAGE: [time,p,dddp]=get_tt_Ps(depth,delta);
%
%  get travel time, ray parameter and d(p)/d(delta) for the phase Ps  
%
% depth = scalar depth for P-S conversion (km)
% delta = row vector of epicentral distances
% earthquake is assumed to be at the surface
%
% time = column vector of travel times (s)
% p    = column vector of ray parameters (s/deg)
% dddp = column vector of d(delta)/d(ray parameter) (rad^2/s)
%
% time, ray parameter and dddp are given in the arrays for each phase and delta
% if ray cannot be interpolated from tables constructed here it is given a value of inf

phase='P     '; depth_phase='S     ';

dScS=[20:100]';                               % set distance range for tables
[tScS,pScS,dddpScS]=get_ttt(phase,depth,dScS');  % interpolate to get t, p, and dddp 
% plot(dScS,pScS,'-',dScS,pScS,'o'),title(phase),pause

%  get dS1, tS1, pS1 (distance, time, ray parameter for upgoing branch of S only)

[dS1,tS1,pS1,dddpS1] = get_tt_up(depth_phase,depth);
% plot(dS1,pS1,'-',dS1,pS1,'o'),title('S or P up'),pause

% interpolate to get d of upgoing S at the ray parameters corresponding to ScS table
% then evaluate  t, p, and dddp for upgoing S at these same distances

dS=interpol(pS1,dS1,pScS);
[tS,pS,dddpS]=get_ttt(depth_phase,depth,dS');  %interpolate to get t, p, and dddp
% plot(dS,pS,'-',dS,pS,'o'),title('S or P up again'),pause

disp(['max ray parameter error is ' num2str(max(abs(pS-pScS))) ]);

% we now have tables of ScS and upgoing S at the same set of ray parameters
% so t, p, dddp of sScS are simply the sums of their values at fixed ray parameter 

dsScS=dS+dScS;
tsScS=tS+tScS;                
psScS=pScS;
dddpsScS=dddpS+dddpScS;

% interpolate tables to get values at desired distances

p=interpol(dsScS,psScS,delta');
time=interpol(dsScS,tsScS,delta');
dddp=interpol(dsScS,dddpScS,delta');

% set interpolate = 1 for interpolation, 0 for extrapolation, then divide to
% give values of inf for extrapolation
interpolate=(delta'>=min(dsScS)) & (delta'<=max(dsScS));    
p=p./interpolate;
time=time./interpolate;
dddp=dddp./interpolate;

