function [delta_out,time,p,dddp,dtdh,ph] = get_tt_up(phase,depth);
%   get_tt_up      get travel times for upgoing rays
% USAGE: [delta_out,time,p,dddp,dtdh,ph] = get_tt_up(phase,depth);
%
% get travel time curves from iasp91 model for up-going rays only
% 
% INPUT PARAMETERS:
%  phase : row character vector, must be either 'P  ' or 'S  '
%  depth : scalar-valued event depth (km)
%
%OUTPUT PARAMETERS:
%  delta_out: column vector of epicentral distances
%  time     : column vector of travel times (s)
%  p        : column vector of ray paraameters (s/deg)
%  dddp     : column vector of d(delta)/d(p) (rad^2/s)
%  dtdh     : column vector of d(time)/d(depth) (km/s)
%  phase_out: array of phase names for above parameters
%              names are in rows

if depth<15  
  delmax=5;
elseif depth<120 
  delmax=12;
else
  delmax=20;
end
nn=[0:.0125:1]; delta=delmax*nn.*nn.*nn;

% interpolate iasp91 tables
[delta_out,time,p,dddp,dtdh,ph] = get_tt(phase,depth,delta);

% remove PKiKP, and include only phases with dddp>0
ind=find(ph(:,2)~=abs('K') & dddp>0);

% ray parameter should be monotonically increasing with increasing distance
% remove rays past first ray in which this is not true
p1=p(ind);
ii=min(find(diff(p1)<0));
if length(ii)>0
  ind=ind(1:ii);
  p1=p(ind);
end
ii=[1;find(diff(p1)~=0)+1];
ind=ind(ii);

% chose appropriate subset of all arrays
p=p(ind);
delta_out=delta_out(ind);
time=time(ind);
dddp=dddp(ind);
dtdh=dtdh(ind);
ph=ph(ind,:);
dmax=delta_out(length(delta_out));
