      program convcss
*=====================================================================
* PURPOSE:
*     This routine will read CSS binary data and convert the data into 
*     SAC formatted files by using the data supplied in file XXXX.wfdisc
*     files. You must awk the wfdisc file for fields 1,5,6,16,21,22,23 
*     and then use that file as input data to this routine.
*     ** (NOTE) **
*     fields 21,22,23 are all used to create the output
*     filename. Make sure to remove any spaces that may
*     between these columns.
*=====================================================================
* AUTHOR: Ken Sumikawa
*=====================================================================
* SUBROUTINES CALLED:zclose,zopen,zwabs,zrabs
*=====================================================================
* MODIFICATION HISTORY:
*    04/08/1987:  Original version.
*    04/05/1988:  commented and fixed zopenc and zclosc to reflect new
*                 SAC modifications.
*    01/05/1989:  Disabled ltime routine and replaced it with idttm (SAC)
*                 Previous problem with time fields is corrected now.
*=====================================================================
*
*     variable declarations
*

      parameter(max=90000)
      character*210 inline
      character*30 datfile,infile,outfile,var(30),tmpvar
      character*8 kstnm,kcmpnm
      dimension yray(max),iray(max)
      real xray,yray,delta,sec
      integer*4 npts,iray,tray1(6),tray2(6)

*
*=====================================================================
*

      write(*,'(a$)')'Enter wfdisc filename: '
      read(*,'(a)')datfile

      close(9)
      open(9,file=datfile,status='old',iostat=k)

      if (k .gt. 0) then
	write(*,'(a)')'Error opening wfdisc file..'
	close(9)
	goto 900
      endif

*
*-READ INLINE STRING FOR SAC HEADER DATA SETS
*


   10 read(9,'(a210)',end=900)inline
      do 15,i=210,1,-1
15    if (inline(i:i) .ne. ' ')goto 16
      write(*,'(a)')' Error reading file information'
      call exit
*
* n=file end
*

16    n=i

*
* Set starting index values for substringing
*

      i=1

17    if (inline(i:i) .eq. ' ') then
	i=i+1
	goto 17
      endif

      i1=i
      j=1
*
* loop to look for white characters in the input sting
* for internal file conversion to sac header variables
*
20       if (i .gt. n) goto 25

	 if (inline(i:i) .eq. ' ') then
            var(j)=inline(i1:i)
	    i=i+1
	    i1=i
	    j=j+1
22            if(inline(i:i) .eq. ' ') then
	        i=i+1
		i1=i
 	        goto 22
	      endif
	    goto 20
	    endif

	 i=i+1
	 goto 20
	
25     var(j)=inline(i1:i-1)

*
*-SUBSTING OUT FIELD PARAMETERS FROM VAR ARRAY
*

      tmpvar=var(1)
      read(tmpvar(1:4),'(I4)')nzyear
      read(tmpvar(5:7),'(I3)')nzjday
      read(var(2),*)sec
      kstnm=var(3)(1:8)
      kcmpnm=var(4)(1:8)
      read(var(5),*)npts
      read(var(6),*)delta
      write(infile,'(A)')var(16)
      tray1(1)=1970
      tray1(2)=0
      tray1(3)=0
      tray1(4)=0
      tray1(5)=0
      tray1(6)=0
      call idttm(tray1,sec,tray2)
*     call ltime(tray1,sec,tray2)


*-Find eliminate the end white characters from inline string
*

      do 30,i=30,1,-1
      if (infile(i:i) .ne. ' ')goto 40
30    continue
40    outfile=infile(1:i)//'.sac'
      ii=i
      delta=1/delta
      ib=0

*
*-READ IN CSS BINARY DATA INTO YRAY.. ASSUME BEGIN TIME 0.0
*

      ifd=7
      call zopen(ifd,infile,'DATA',0,ierr)
      call zrabs (ifd,iray,npts,ib,ierr)
      call zclose(ifd,ierr)

*   
*-LOOP TO EXCHANGE INTEGER ARRAY TO REAL ARRAY DATA
*
         do 50,i=1,npts
   50    yray(i)=iray(i)


*
*-DECLARE NECESSARY HEADER VARIABLES
*

      call newhdr
      call setnhv('NPTS',npts,nerr)
      call setfhv('B',ib,nerr)
      call setfhv('DELTA',delta,nerr)
      call setnhv('NZYEAR',nzyear,nerr)
      call setnhv('NZJDAY',nzjday,nerr)
      call setnhv('NZHOUR',tray2(3),nerr)
      call setnhv('NZMIN',tray2(4),nerr)
      call setnhv('NZSEC',tray2(5),nerr)
      call setnhv('NZMSEC',tray2(6),nerr)
      call setkhv('KSTNM',kstnm,nerr)
      call setkhv('KCMPNM',kcmpnm,nerr)
      call setkhv('KUSER0',var(20)(1:8),nerr)
      call setkhv('KUSER1',var(21)(1:8),nerr)
      
*     
*-WSAC0 TO WRITE OUT SAC FILE WITH EVENLY SPACE DATA
*
      call wsac0(outfile(1:ii+4),xray,yray,nerr)

      go to 10
  900 close(9)
      end
