      program sgftops
*=====================================================================
* PURPOSE:  To convert the contents of a SAC Graphics File (SGF) to a
*           file containing POSTSCRIPT formatted commands.
*=====================================================================
* MODULE/LEVEL:  sgf/1
*=====================================================================
* GLOBAL INPUT:
*    mach:    mcmsg, mcpfn, mcpw, munout
*=====================================================================
* SUBROUTINES CALLED:
*    local:   plotfile
*    saclib:  zgimsg, zgpmsg, indexb, poptok, modcase,
*=====================================================================
* MODIFICATION HISTORY:
*    910709:  Commented out the "EndProlog" and "Trailer" commands.
*    900310:  Added logic to create fixed size plots.
*    870930:  Rewrote using the F77 SGF shell.
*    870502:  Made more robust and readable.
*    850310:  Original version in "C" by Tom Owens at U. of Missouri.
*=====================================================================
* DOCUMENTED/REVIEWED:  870930
*=====================================================================

      include 'mach'

      character*(mcmsg) message, prompt
      character*(mcpw) token
      character*(mcpfn) kifile, kofile
      logical id

      parameter (mhelp=7)
      character*(80) khelp(mhelp)
      data khelp/
     # 'This program converts the contents of a SGF to a file',
     # 'containing graphics commands in POSTSCRIPT format.',
     # 'To use enter the name of a SGF, the name of an output file,',
     # 'and an optional integer from 1 to 8 specifying the width',
     # 'of all line segments.  The default width is 1.',
     # 'A value of 2 produces lines which are twice as wide.',
     # 'If the output file is omitted, output is sent to the terminal.'/

* PROCEDURE:

* - Get message from input line or prompt user.

      call zgimsg(message)
      nc=indexb(message)
  100 if(nc.le.0)then
        do 200 j=1,mhelp
        nc=indexb(khelp(j))
  200   write(munout,'(a)')khelp(j)(1:nc)
        write(munout,'(1x)')
        prompt='Enter the SGF name, the output name, and linewidth: $'
        call zgpmsg(prompt,message)
      endif

* - Decode input.
*   This is the name of the input SGF, the output file, and the options.

      iwidth=1
      lterm=.false.

      ic=0
      nc=indexb(message)

      call poptok(message,nc,ic,ic1,ic2,itype)
      kifile=message(ic1:ic2)

      call poptok(message,nc,ic,ic1,ic2,itype)
      if(itype.gt.0)then
        token=message(ic1:ic2)
        call cnvati(token,int,nerr)
        if(nerr.eq.0)then
          iwidth=min0(8,max0(1,int))
          lterm=.true.
        else
          kofile=message(ic1:ic2)
          lterm=.false.
        endif
      endif

 300  call poptok(message,nc,ic,ic1,ic2,itype)
      if(itype.gt.0)then
        token=message(ic1:ic2)
        call cnvati(token,int,nerr)
        if(nerr.eq.0)then
          iwidth=min0(8,max0(1,int))
        else
          write(munout,'(2a/1x)')'ERROR: unknown option = ',token
          nc=0
          go to 100
        endif
      endif

* - Open output file if appropriate.

      if(lterm)then
        nofun=munout
      else
C        call zgtfun(nofun,nerr)
        if(nerr.ne.0)go to 9000
        call znfile(nofun,kofile,'TEXT',ntused,nerr)
        if(nerr.ne.0)go to 9000
      endif

* - Add the POSTSCRIPT initialization commands to file.

      write(nofun,'(a)')'%!PS-Adobe-1.0'
      write(nofun,'(a)')'/Helvetica findfont 8 scalefont setfont'

* -- Define several linestyles.
      write(nofun,'(a)')'/sl {[] 0 setdash} def'
      write(nofun,'(a)')'/dl {[50 75] 0 setdash} def'
      write(nofun,'(a)')'/ddl {[300 250 100 250] 0 setdash} def'
      write(nofun,'(a)')'/sdl {[100 200] 0 setdash} def'
      write(nofun,'(a)')'/ldl {[400 300] 0 setdash} def'

* -- Abbreviations.
      write(nofun,'(a)')'/L { lineto } def'
      write(nofun,'(a)')'/m { moveto } def'

* -- Linewidth.
      ipswidth=15*iwidth
      write(nofun,'(i4,1x,a)')ipswidth,'setlinewidth'

* -- Translation, rotation, and scaling to default plot size
*    which is at (10",7.5"), landscape, origin lower left at (0.5,0.5).
      write(nofun,'(a)')'gsave'
      write(nofun,'(a)')'72 8 mul 36 translate'
      write(nofun,'(a)')'90 rotate'
      write(nofun,'(a)')'10 72 mul 32000 div 7.5 72 mul 24000 div scale'

* - Process input SGF.

      call plotfile(kifile,nofun,nerr)
      if(nerr.ne.0)go to 8888
        
* - Add to the POSTSCRIPT termination commands to file.

      write(nofun,'(a)')'stroke'
      write(nofun,'(a)')'showpage'
      write(nofun,'(a)')'grestore'
*     write(nofun,'(a)')'%%EndProlog'
*     write(nofun,'(a)')'%%Trailer'
    
* - Close output file and terminate program.

 8888 if(.not.lterm)call zclose(nofun,ncerr)
      call zexit

* - Handle exceptions.

 9000 nc=indexb(kofile)
      write(munout,'(2a)')'ERROR: opening output file ',kofile(1:nc)
      go to 8888

      end

      subroutine plotfile(kifile,nofun,nerr)
*=====================================================================
* PURPOSE:  To plot the contents of a SGF.
*=====================================================================
* INPUT ARGUMENTS:
*    kifile:  name of input SGF to merge. [c]
*    nofun:   fortran file unit to write to. [i]
*=====================================================================
* OUTPUT ARGUMENTS:
*    nerr:    error return flag. [i]
*=====================================================================
* MODULE/LEVEL:  sgf/2
*=====================================================================
* GLOBAL INPUT:
*    mach:    munout
*=====================================================================
* SUBROUTINES CALLED:
*    local:   plotbuffer
*    saclib:  zopen, zrabs, zclose
*=====================================================================
* MODIFICATION HISTORY:
*    870115:  Original version.
*=====================================================================
* DOCUMENTED/REVIEWED:  870115
*=====================================================================

      include 'mach'
      character*(*) kifile
      parameter (mbuf=5200)
      integer*2 buf(mbuf)

      nerr=0

* - Open input SGF.

C      call zgtfun(nifun,nerr)
      call zopen(nifun,kifile,'RODATA',nlen,nerr)
      if(nerr.ne.0)go to 9000

* - Loop through input SGF, one buffer at a time.

      ilcdsk=0
      ibuf=0
      ldone=.false.
 1000 if(.not.ldone)then

* -- Read in number of long (32-bit) words in next buffer.
        call zrabs(nifun,ilnbuf,1,ilcdsk,nerr)
        if (nerr.ne.0) go to 9100
        ilcdsk=ilcdsk+1

* -- Read in buffer.
        call zrabs(nifun,buf,ilnbuf,ilcdsk,nerr)
        if (nerr.ne.0) go to 9100
        ilcdsk=ilcdsk+ilnbuf
        ibuf=ibuf+1

* -- Scale contents of buffer.
        nlnbuf=2*ilnbuf
        call plotbuffer(buf,nlnbuf,nofun,ldone)

* -- Loop until done.
        go to 1000
      endif

* - Close input SGF.

      call zclose(nifun,ncerr)

 8888 return

 9000 nc=indexb(kifile)
      write(munout,'(2a)')'ERROR: opening file ',kifile(1:nc)
      go to 8888

 9100 nc=indexb(kifile)
      write(munout,'(2a)')'ERROR: reading file ',kifile(1:nc)
      call zclose(nifun,ncerr)
      go to 8888

      end

      subroutine plotbuffer(buf,nlnbuf,nofun,ldone)
*=====================================================================
* PURPOSE:  To plot a SGF buffer.
*=====================================================================
* INPUT ARGUMENTS:
*    buf:     buffer of graphics commands. [si]
*    nlnbuf:  (short integer) length of buf. [i]
*    nofun:   output fortran file unit. [i]
*=====================================================================
* OUTPUT ARGUMENTS:
*    ldone:   set to .true. when end-of-frame command encounted. [l]
*=====================================================================
* MODULE/LEVEL:  sgf/3
*=====================================================================
* GLOBAL INPUT:
*    mach:    mcmsg
*=====================================================================
* SUBROUTINES CALLED:
*    local:   validateloc2, encodeloc, encodeline, encodesize
*=====================================================================
* MODIFICATION HISTORY:
*    870115:  Original version.
*=====================================================================
* DOCUMENTED/REVIEWED:  870115
*=====================================================================

      include 'mach'
      integer*2 buf
      dimension buf(*)
      character*(mcmsg) ktext, string

      parameter (mcbuf=80)
      character*(1) cbuf
      dimension cbuf(mcbuf)
      
      parameter (maxline=5)
      character*(3) klines(maxline)
     
      parameter (mvecs=400)

      save cbuf, ncbuf, lmove, ixloc, iyloc, iline, nvecs
      data ncbuf/0/,iline/1/
      data klines/'sl','dl','ddl','sdl','ldl'/
      data nvecs/0/

* PROCEDURE:

* - Initialize some variables.

      jbuf=1
      ldone=.false.
      nbadloc=0

* - Loop on each command in buffer:

 1000 if(jbuf.le.nlnbuf)then
        icom=buf(jbuf)

* -- Force printer to stroke the vectors after every 400 commands.
*    This is needed on some devices to clear internal vector buffers.
*    Must follow this with a move to the last point.

        nvecs=nvecs+1
        if(nvecs.ge.mvecs)then
          write(nofun,'(a)')'stroke'
          write(nofun,'(2i6,1x,a)')ixloc,iyloc,'m'
          nvecs=0
        endif
 
* -- Draw command.

        if(icom.ge.0)then
          call validateloc2(buf(jbuf),buf(jbuf+1),ixloc,iyloc,nbadloc)
          write(nofun,'(2i6,1x,a)')ixloc,iyloc,'L'
          jbuf=jbuf+2

* -- Move command

        elseif(icom.eq.-3)then
          call validateloc2(buf(jbuf+2),buf(jbuf+3),ixloc,iyloc,nbadloc)
          write(nofun,'(2i6,1x,a)')ixloc,iyloc,'m'
          jbuf=jbuf+2+buf(jbuf+1)

* -- Color command.
*     "icolor" is a positive integer from 1 to the maximum number
*     of colors in the color table.
*    (This command is ignored in this program.)

        elseif(icom.eq.-4)then
          jbuf=jbuf+2+buf(jbuf+1)

* -- Hardware text command.
*     "text" is the character string.
*     "nctext" is the character count.

        elseif(icom.eq.-5)then
          nctext=buf(jbuf+2)
          call zgetc(buf(jbuf+3),cbuf(ncbuf),nctext)
          write(nofun,'(a)')'gsave'
          string='32000 72 10 mul div 24000 72 10 mul div scale'
          nc=indexb(string)
          write(nofun,'(a)')string(1:nc)
          write(nofun,'(a)')ktext(1:nctext)
          write(nofun,'(a)')'grestore'       
          jbuf=jbuf+2+buf(jbuf+1)

* -- Hardware text size command.
*     "width" is text width in viewspace coordinates (0.0 to 1.0).
*     "height" is text height.
*    (This command is ignored by this program.)

        elseif(icom.eq.-6)then
          width= float(buf(jbuf+2))/32000.
          height=float(buf(jbuf+3))/32000.
          jbuf=jbuf+2+buf(jbuf+1)

* -- Linestyle command.
*     "iline" is positive integer.
*     A value of 1 is a solid line.  Other values are device dependent.

        elseif(icom.eq.-7)then
          iline=buf(jbuf+2)
          iline=iabs(mod(iline-1,maxline))+1
          write(nofun,'(a)')'stroke'       
          write(nofun,'(a)')klines(iline)
          jbuf=jbuf+2+buf(jbuf+1)

* -- Plot size command.
*     "xsize" is requested horizontal size of plot in inches.
*    Add a new scaling from 10" width to requested width.
        elseif(icom.eq.-8)then
          xsize=0.01*float(buf(jbuf+2))
          jbuf=jbuf+2+buf(jbuf+1)
          xscale=xsize/10.0
          yscale=xscale
          write(nofun,'(2f14.3,1x,a)')xscale,yscale,'scale'

* -- No-op command.  Used to fill a buffer to a 32-bit word boundary.

        elseif(icom.eq.-1)then
          jbuf=jbuf+1

* -- End-of-plot command.

        elseif(icom.eq.-2)then

          ldone=.true.
          jbuf=jbuf+2
          go to 8888

* -- Skip unknown opcodes and continue.

        else
          jbuf=jbuf+2+buf(jbuf+1)

        endif

* - Loop until buffer is empty.
        go to 1000

      endif

 8888 return

      end

      subroutine validateloc2(ixin,iyin,ixout,iyout,nbadloc)
*=====================================================================
* PURPOSE:  To validate a SAC graphics file location.
*           Also converts location from short integers to long integers.
*=====================================================================
* INPUT ARGUMENTS:
*    ixin:    sgf x location from file. [si]
*    iyin:    sgf y location from file. [si]
*=====================================================================
* OUTPUT ARGUMENTS:
*    ixout:   sgf x location after validation. [i]
*    iyout:   sgf y location after validation. [i]
*    nbadloc: incremented by 1 if the input location was bad. [i]
*=====================================================================
* MODULE/LEVEL:  sgf/4
*=====================================================================
* GLOBAL INPUT:
*    mach:
*=====================================================================
* MODIFICATION HISTORY:
*    870929:  Made maximum x and y locations into parameters.
*    851017:  Original version.
*=====================================================================
* DOCUMENTED/REVIEWED:  851017
*=====================================================================

      include 'mach'
      parameter (ixmax=32000, iymax=24000)

      integer*2 ixin, iyin
      integer*4 ixout, iyout

* PROCEDURE:

      ixout=ixin
      if(ixout .lt. 0)then
        ixout=0
        nbadloc=nbadloc+1
      elseif(ixout .gt. ixmax)then
        ixout=ixmax
        nbadloc=nbadloc+1
      endif

      iyout=iyin
      if(iyout .lt. 0)then
        yout=0
        nbadloc=nbadloc+1
      elseif(iyout .gt. iymax)then
        iyout=iymax
        nbadloc=nbadloc+1
      endif

 8888 return

      end
